( cd usr/lib64 ; rm -rf libGL.so.1 )
( cd usr/lib64 ; ln -sf libGL.so.1.2 libGL.so.1 )
( cd usr/lib64 ; rm -rf libGLw.so.1 )
( cd usr/lib64 ; ln -sf libGLw.so.1.0.0 libGLw.so.1 )
( cd usr/lib64 ; rm -rf libglut.so.3 )
( cd usr/lib64 ; ln -sf libglut.so.3.7.1 libglut.so.3 )
( cd usr/lib64 ; rm -rf libglut.so )
( cd usr/lib64 ; ln -sf libglut.so.3 libglut.so )
( cd usr/lib64 ; rm -rf libGLU.so )
( cd usr/lib64 ; ln -sf libGLU.so.1 libGLU.so )
( cd usr/lib64 ; rm -rf libGLw.so )
( cd usr/lib64 ; ln -sf libGLw.so.1 libGLw.so )
( cd usr/lib64 ; rm -rf libGLU.so.1 )
( cd usr/lib64 ; ln -sf libGLU.so.1.3.070003 libGLU.so.1 )
( cd usr/lib64 ; rm -rf libGL.so )
( cd usr/lib64 ; ln -sf libGL.so.1 libGL.so )
